DirtyRectTracker

Struct DirtyRectTracker 

pub struct DirtyRectTracker { /* private fields */ }
Dirty rectangle tracking for visualization.

Tracks repainted screen regions for the diagnostic HUD overlay.

Example

use martensite_devtools::hud::{DirtyRectTracker, Rect};

let mut tracker = DirtyRectTracker::new(64);
tracker.add(Rect::new(0, 0, 100, 100));
tracker.add(Rect::new(50, 50, 100, 100));
assert_eq!(tracker.rects().len(), 2);
assert!(tracker.total_area() > 0);

Implementations

Source

impl DirtyRectTracker

pub fn new(max_rects: usize) -> Self

Creates a new tracker with the given maximum number of rectangles.

Example
use martensite_devtools::hud::DirtyRectTracker;

let tracker = DirtyRectTracker::new(32);
assert!(tracker.is_empty());
pub fn add(&mut self, rect: Rect)

Adds a dirty rectangle. If the tracker is full, the oldest rectangle is dropped.

Example
use martensite_devtools::hud::{DirtyRectTracker, Rect};

let mut tracker = DirtyRectTracker::new(2);
tracker.add(Rect::new(0, 0, 10, 10));
tracker.add(Rect::new(10, 10, 10, 10));
tracker.add(Rect::new(20, 20, 10, 10)); // drops oldest
assert_eq!(tracker.rects().len(), 2);
pub fn rects(&self) -> &[Rect]

Returns the tracked rectangles.

pub fn clear(&mut self)

Clears all tracked rectangles.

pub fn total_area(&self) -> u64

Returns the total area of all tracked rectangles.

Example
use martensite_devtools::hud::{DirtyRectTracker, Rect};

let mut tracker = DirtyRectTracker::new(10);
tracker.add(Rect::new(0, 0, 100, 100));
assert_eq!(tracker.total_area(), 10_000);
pub fn is_empty(&self) -> bool

Returns true if no rectangles are tracked.

pub fn len(&self) -> usize

Returns the number of tracked rectangles.